package com.faranegar.barcode_reader;


import android.content.Intent;
import android.content.pm.PackageManager;

import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * BarcodeReaderPlugin
 */
public class BarcodeReaderPlugin implements MethodCallHandler {
    private static AndroidBarcodeScannerFactory androidBarcode;

    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        if (registrar.activity() != null) {
            if(checkPermission(registrar))
                registrar
                        .platformViewRegistry()
                        .registerViewFactory(
                                "com.faranegar/androidbarcodescanner"
                                , new AndroidBarcodeScannerFactory(registrar.messenger(), registrar.activity()));
        }
    }

    private static boolean checkPermission(final Registrar registrar) {
        if (ContextCompat.checkSelfPermission(
               registrar.activity() , android.Manifest.permission.CAMERA) ==
                PackageManager.PERMISSION_GRANTED) {
            // You can use the API that requires the permission.
            return true;
        } else {
            registrar.addRequestPermissionsResultListener(new PluginRegistry.RequestPermissionsResultListener() {
                @Override
                public boolean onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
                    switch (requestCode) {
                        case 5505:
                            if (grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                                //granted
                                registerWith(registrar);
                                return true;
                            } else {
                                //not granted
                                if(ActivityCompat.shouldShowRequestPermissionRationale(registrar.activity(), android.Manifest.permission.CAMERA))
                                    registerWith(registrar);
                            }
                            break;

                    }
                    return false;
                }
            });
            ActivityCompat.requestPermissions(registrar.activity(), new String[]{android.Manifest.permission.CAMERA}, 5505);
            return false;
        }

    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        if (call.method.equals("getPlatformVersion")) {
            result.success("Android " + android.os.Build.VERSION.RELEASE);
        } else {
            result.notImplemented();
        }
    }
}
